@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::array::str_comma_sep;
 
-our $DATE = '2016-05-22'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-05-23'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -44,13 +44,13 @@ Data::Sah::Coerce::perl::array::str_comma_sep - Coerce array from a comma-separa
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Coerce::perl::array::str_comma_sep (from Perl distribution Data-Sah-CoerceRule-array-str_comma_sep), released on 2016-05-22.
+This document describes version 0.005 of Data::Sah::Coerce::perl::array::str_comma_sep (from Perl distribution Data-Sah-CoerceRule-array-str_comma_sep), released on 2016-05-23.
 
 =head1 DESCRIPTION
 
 The rule is not enabled by default. You can enable it in a schema using e.g.:
 
- ["array*", of=>"int", "x.coerce_from"=>["str_comma_sep"]]
+ ["array*", of=>"int", "x.coerce_rules"=>["str_comma_sep"]]
 
 =for Pod::Coverage ^(meta|coerce)$
 
