@@ -1,7 +1,7 @@
 package Data::Sah::CoerceRule::array::str_comma_sep;
 
-our $DATE = '2016-05-22'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-05-23'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 1;
 # ABSTRACT: Coerce array from a comma-separated items in a string
@@ -18,7 +18,7 @@ Data::Sah::CoerceRule::array::str_comma_sep - Coerce array from a comma-separate
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::CoerceRule::array::str_comma_sep (from Perl distribution Data-Sah-CoerceRule-array-str_comma_sep), released on 2016-05-22.
+This document describes version 0.005 of Data::Sah::CoerceRule::array::str_comma_sep (from Perl distribution Data-Sah-CoerceRule-array-str_comma_sep), released on 2016-05-23.
 
 =head1 DESCRIPTION
 
@@ -26,7 +26,7 @@ This distribution contains Data::Sah coercion rule to coerce array from a
 comma-separated items in a string. The rule is not enabled by default. You can
 enable it in a schema using e.g.:
 
- ["array*", of=>"int", "x.coerce_from"=>["str_comma_sep"]]
+ ["array*", of=>"int", "x.coerce_rules"=>["str_comma_sep"]]
 
 =head1 HOMEPAGE
 
